@@ -1,6 +1,3 @@
-// Remove the line below if you are copying this to your own project
-extern crate bevy_flycam;
-
 use bevy::prelude::*;
 use bevy_flycam::MovementSettings;
 use bevy_flycam::PlayerPlugin;
@@ -9,7 +6,7 @@ use bevy_flycam::PlayerPlugin;
 //https://github.com/bevyengine/bevy/blob/latest/examples/3d/3d_scene.rs
 
 fn main() {
-    App::build()
+    App::new()
         .insert_resource(Msaa { samples: 4 })
         .add_plugins(DefaultPlugins)
         .add_plugin(PlayerPlugin)
@@ -17,7 +14,7 @@ fn main() {
             sensitivity: 0.00015, // default: 0.00012
             speed: 12.0,          // default: 12.0
         })
-        .add_startup_system(setup.system())
+        .add_startup_system(setup)
         .run();
 }
 
@@ -41,8 +38,13 @@ fn setup(
         ..Default::default()
     });
     // light
-    commands.spawn_bundle(LightBundle {
+    commands.spawn_bundle(PointLightBundle {
         transform: Transform::from_xyz(4.0, 8.0, 4.0),
         ..Default::default()
     });
+
+    info!("Move camera around by using WASD for lateral movement");
+    info!("Use Left Shift and Spacebar for vertical movement");
+    info!("Use the mouse to look around");
+    info!("Press Esc to hide or show the mouse cursor");
 }
